#ifndef __USER_H__
#define __USER_H__

int translate_oct();
int interp_call();
int INPUT();
int OUTGR();
int min1();
int max1();
double amax1();
double amin1();
double erfr();
double crs();
double crsd();
double crsdr2();
double crsdd();
void crs_full();
int COGRR1();
int POINT();
int LINEQS();
void clean();
int point_save();

#endif
